c-----------------------------------------------------------------------
c ... Global Parameters
c-----------------------------------------------------------------------

c ... Maximum character size of input file name
      integer PATH_MAX
      parameter (PATH_MAX = 255)

c ... Maximum number of pixels and lines in a 1km scan

      integer MAX_PIXEL, MAX_LINE
      parameter( MAX_PIXEL = 1354, MAX_LINE = 10)

c ... Total number of bands in input file
      integer INBAND
      parameter( INBAND = 36 )

c ... Number of 1km NIR bands

      integer NBANDS
      parameter( NBANDS = 4 )
      
c ... Number of bands in Direct Broadcast Output file 
c (presently 1 water vapor field, include land/sea flag and cloud flag later)

      integer OUT_BAND
      parameter (OUT_BAND = 1)
c ... Bad data value

      real BAD_VALUE
      parameter( BAD_VALUE = -0.5 )

c-----------------------------------------------------------------------

c ... Neural network variables
c ... Dimension of input vector
      integer  DIMI
      parameter( DIMI = 7 )
c ... Dimension of output vector
      integer  DIMO
      parameter( DIMO = 1 )
      
      integer DIMH
      parameter( DIMH = 9 )
      
      integer BIAS_H
      parameter( BIAS_H = 1 )
      integer BIAS_I
      parameter( BIAS_I = 1 )
      
c ... Minima and maxima of training data
      real MIN_TRAIN_IN( DIMI )
      real MAX_TRAIN_IN( DIMI )

c ... Neural network matrices
      real INV( DIMI + 1, DIMH )      
      real OUTV( DIMH + 1, DIMO )

c ... Scale factors for input and output
      real OFFSET1(DIMI + DIMO), OFFSET2(DIMI + DIMO), SCALE(DIMI + DIMO)
      
c ... Temperature of the sigmoide
      real  TEMPERATURE
      parameter( TEMPERATURE = 1.0 )
      
c-----------------------------------------------------------------------
c ... REAL global variables stored in COMMON
c-----------------------------------------------------------------------

c ... MODIS L1B input radiance data for all 1km IR bands

      real RADIANCE1( MAX_PIXEL, MAX_LINE, NBANDS )

c ... MODIS geolocation input latitude and longitude data for 1km bands

      real VIEW( MAX_PIXEL, MAX_LINE ),
     &     SOLZ( MAX_PIXEL, MAX_LINE ),
     &     SENA( MAX_PIXEL, MAX_LINE ),
     &     SOLA( MAX_PIXEL, MAX_LINE )

c ... NN input vector
      real NN_INPUT( DIMI + 1 )
      
c ... common output products at full resolution

      real WVNIR_OUT( MAX_PIXEL, MAX_LINE)

c-----------------------------------------------------------------------
c ... INTEGER global variables stored in COMMON
c-----------------------------------------------------------------------

c ... 1km IR band numbers

      integer BANDS( NBANDS ) 
          
c-----------------------------------------------------------------------
c ### COMMON blocks to hold global variables
c ### (Arrays are listed in the order REALs, INTEGERs, BYTEs)
c ### MODWVNIR_DATA holds data which is defined in during runtime.
c ### MODWVNIR_NN_DATA holds fixed neural network data which is
c ### defined only once during compilation
c-----------------------------------------------------------------------

      common / MODWVNIR_DATA /
     &  RADIANCE1, VIEW,SOLZ,SENA,SOLA,
     &  NN_INPUT, 
     &  WVNIR_OUT,
     &  BANDS

      common / MODWVNIR_NN_DATA /
     &  MIN_TRAIN_IN, MAX_TRAIN_IN, INV, OUTV,
     &  OFFSET1, OFFSET2, SCALE

c ... Debug information
      integer debug
c      common / modwvnir_debug / debug

