#!/bin/tcsh -f
#
# This script is a simple example of how to run the IMAPP Level 2
# MODIS NIR water vapor processing.
#
# It assumes that you already extracted the flat binary 
# input files (MOD021km (1000m.img) and MOD03 (geo.img) and runs the 
# IMAPP MODIS NIR water vapor software.
#
# Attention: It is assumed that the header files
# are located in the same directory as the appropriate
# flat binaries and that their names only differ by
# the respective suffix
# e.g. /tmp/data/t1.04266.1538.1000m.img ->/tmp/data/t1.04266.1538.1000m.hdr
# 
# Just call the script without parameters to get a short help message.
#
# If you want to call the script from any directory other than wvnir/scripts
# you have to modify the first line of code where the (relative) path to the
# executable is given.
#
# Originally written by Peter Albert September 2004
# peter.albert@wew.fu-berlin.de
#
# Modiy this line if you want to call the script
# from any other directory than wvnir/scripts

set wvnir_exe=../src/wvnir.exe


if ($# != 4) then
	echo 
	echo "usage:\t$0 FIL1KM_IMG FILGEO_IMG FILWVNIR_IMG 0|1"
	echo
	echo "where\tFIL1KM_IMG is the flat binary MOD021km file"
	echo "\tFILGEO_IMG is the flat binary MOD03 file"
	echo "\tFILWVNIR_IMG is the flat binary output file"
	echo "\t0: no status output | 1: some status output from WVNIR retrieval "
	echo
	echo "Attention: It is assumed that the header files"
	echo "are located in the same directory as the appropriate"
	echo "flat binaries and that their names only differ by"
	echo "the respective suffix"
	echo "e.g. /tmp/data/t1.04266.1538.1000m.img ->/tmp/data/t1.04266.1538.1000m.hdr"
	echo
	exit 1
endif

set FIL1KM_IMG=$1
set FILGEO_IMG=$2
set FILWVNIR_IMG=$3
set debug=$4


set FIL1KM_HDR=${FIL1KM_IMG:r}.hdr
set FILGEO_HDR=${FILGEO_IMG:r}.hdr
set FILWVNIR_HDR=${FILWVNIR_IMG:r}.hdr


echo "L1B_1KM_NAME=${FIL1KM_IMG}" > wvnir.$$.cfg
echo "L1B_1KM_HDR=${FIL1KM_HDR}" >> wvnir.$$.cfg
echo "L1B_1KM_REQ=MANDATORY" >> wvnir.$$.cfg
echo "GEO_1KM_NAME=${FILGEO_IMG}" >> wvnir.$$.cfg
echo "GEO_1KM_HDR=${FILGEO_HDR}" >> wvnir.$$.cfg
echo "GEO_1KM_REQ=MANDATORY" >> wvnir.$$.cfg
echo "MODWVNIR_NAME=${FILWVNIR_IMG}" >> wvnir.$$.cfg
echo "MODWVNIR_HDR=${FILWVNIR_HDR}" >> wvnir.$$.cfg
echo "MODWVNIR_REQ=MANDATORY	" >> wvnir.$$.cfg
echo "debug=${debug}" >> wvnir.$$.cfg

$wvnir_exe wvnir.$$.cfg

rm -f wvnir.$$.cfg
